package dev.struchkov.yookassa.sdk.model.common;

import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import dev.struchkov.yookassa.sdk.jackson.CurrencyDeserializer;
import dev.struchkov.yookassa.sdk.jackson.CurrencySerializer;
import dev.struchkov.yookassa.sdk.model.Required;
import lombok.AccessLevel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.ToString;

import java.util.Currency;

@Getter
@Setter
@Builder
@ToString
@NoArgsConstructor
@AllArgsConstructor(access = AccessLevel.PRIVATE)
public class Amount {

    /**
     * Сумма в выбранной валюте. Выражается в виде строки и пишется через точку, например 10.00. Количество знаков после точки зависит от выбранной валюты.
     */
    @Required
    private String value;

    /**
     * Трехбуквенный код валюты в формате <a href="https://www.iso.org/iso-4217-currency-codes.html">ISO-4217</a>. Пример: RUB. Должен соответствовать валюте субаккаунта (recipient.gateway_id), если вы разделяете потоки платежей, и валюте аккаунта (shopId в <a href="https://yookassa.ru/my">личном кабинете</a>), если не разделяете.
     */
    @JsonSerialize(using = CurrencySerializer.class)
    @JsonDeserialize(using = CurrencyDeserializer.class)
    @Required
    private Currency currency;

}
