package dev.struchkov.yookassa.sdk.model.common;

import com.fasterxml.jackson.annotation.JsonProperty;
import dev.struchkov.yookassa.sdk.model.Required;
import lombok.AccessLevel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;

@Getter
@Setter
@Builder
@NoArgsConstructor
@AllArgsConstructor(access = AccessLevel.PRIVATE)
public class Customer {

    /**
     * Для юрлица — название организации, для ИП и физического лица — ФИО. Если у физлица отсутствует ИНН, в этом же параметре передаются паспортные данные. Не более 256 символов.
     * Онлайн-кассы, которые поддерживают этот параметр: <b>Orange Data, Атол Онлайн.</b>
     */
    @JsonProperty("full_name")
    private String fullName;

    /**
     * ИНН пользователя (10 или 12 цифр). Если у физического лица отсутствует ИНН, необходимо передать паспортные данные в параметре full_name.
     * Онлайн-кассы, которые поддерживают этот параметр: Orange Data, Атол Онлайн.
     */
    private String inn;

    /**
     * Электронная почта пользователя для отправки чека. Обязательный параметр, если не передан phone.
     */
    @Required(alternative = "phone")
    private String email;

    /**
     * Телефон пользователя для отправки чека. Указывается в формате ITU-T E.164, например 79000000000. Обязательный параметр, если не передан email.
     */
    @Required(alternative = "email")
    private String phone;

}
