package dev.struchkov.yookassa.sdk.model.request;

import com.fasterxml.jackson.annotation.JsonProperty;
import dev.struchkov.yookassa.sdk.model.common.Payment;
import dev.struchkov.yookassa.sdk.model.common.Receipt;
import lombok.AccessLevel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.experimental.SuperBuilder;

import java.util.UUID;

@Getter
@Setter
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor(access = AccessLevel.PRIVATE)
public class PaymentRequest extends Payment {

    /**
     * Данные, необходимые для инициирования выбранного сценария подтверждения платежа пользователем. Подробнее о <a href="https://yookassa.ru/developers/payment-acceptance/getting-started/payment-process#user-confirmation">сценариях подтверждения</a>
     */
    private Confirmation confirmation;

    /**
     * Данные для формирования чека.
     * Необходимо передавать в этих случаях:
     * вы компания или ИП, используете решение ЮKassa для оплаты по 54-ФЗ  и отправляете данные для формирования чеков по одному из сценариев: Платеж и чек одновременно  или Сначала чек, потом платеж ;
     * вы самозанятый и используете решение ЮKassa для автоотправки чеков .
     */
    private Receipt receipt;

    private UUID idempotenceKey;

    @Getter
    @Setter
    @Builder
    @NoArgsConstructor
    @AllArgsConstructor(access = AccessLevel.PRIVATE)
    public static class Confirmation {

        private String type;

        @JsonProperty("return_url")
        private String returnUrl;

    }

}
