package dev.struchkov.yookassa.sdk.model.webhook;

import com.fasterxml.jackson.annotation.JsonProperty;
import dev.struchkov.yookassa.sdk.model.common.Amount;
import dev.struchkov.yookassa.sdk.model.common.Payment;
import dev.struchkov.yookassa.sdk.model.common.Recipient;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

import java.time.ZonedDateTime;

@Getter
@Setter
@ToString
public class PaymentWebhook extends Payment {

    @JsonProperty("id")
    private String id;

    @JsonProperty("status")
    private PaymentStatus status;

    @JsonProperty("income_amount")
    private Amount incomeAmount;

    @JsonProperty("recipient")
    private Recipient recipient;

    @JsonProperty("payment_method")
    private PaymentMethod paymentMethod;

    /**
     * Время подтверждения платежа. Указывается по UTC и передается в формате ISO 8601.
     */
    @JsonProperty("captured_at")
    private ZonedDateTime capturedAt;

    /**
     * Время создания заказа. Указывается по UTC и передается в формате ISO 8601. Пример: 2017-11-03T11:52:31.827Z
     */
    @JsonProperty("created_at")
    private ZonedDateTime createdAt;

    @JsonProperty("test")
    private boolean test;

    @JsonProperty("refunded_amount")
    private Amount refundedAmount;

    /**
     * Признак оплаты заказа.
     */
    @JsonProperty("paid")
    private boolean paid;

    /**
     * Возможность провести возврат по API.
     */
    @JsonProperty("refundable")
    private boolean refundable;

    @JsonProperty("authorization_details")
    private AuthorizationDetails authorizationDetails;

    @JsonProperty("cancellation_details")
    private CancellationDetails cancellationDetails;

}
