package dev.struchkov.yookassa.sdk;

import dev.struchkov.yookassa.sdk.model.request.PaymentRequest;
import dev.struchkov.yookassa.sdk.model.response.PaymentResponse;
import dev.struchkov.yookassa.sdk.util.IdempotenceKeyClientFilter;
import dev.struchkov.yookassa.sdk.util.YookassaExceptionHandler;
import io.smallrye.mutiny.Uni;
import org.eclipse.microprofile.rest.client.annotation.ClientHeaderParam;
import org.eclipse.microprofile.rest.client.annotation.RegisterProvider;
import org.eclipse.microprofile.rest.client.inject.RegisterRestClient;

import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;

@Path("v3/payments")
@Consumes(MediaType.APPLICATION_JSON)
@Produces(MediaType.APPLICATION_JSON)
@RegisterRestClient(baseUri = "https://api.yookassa.ru")
@ClientHeaderParam(name = "Authorization", value = "${yookassa.token}")
@RegisterProvider(YookassaExceptionHandler.class)
@RegisterProvider(IdempotenceKeyClientFilter.class)
public interface YooKassaPaymentClient {

    default String getIdempotenceKeyFromPaymentRequest(String headerName, PaymentRequest paymentRequest) {
        if ("Idempotence-Key".equals(headerName)) {
            return paymentRequest.getIdempotenceKey().toString();
        }
        throw new UnsupportedOperationException("unknown header name");
    }

    @POST()
    Uni<PaymentResponse> sendInvoice(PaymentRequest paymentRequest);

}
