package dev.struchkov.yookassa.sdk;

import dev.struchkov.yookassa.sdk.context.YooKassaWebhookConsumer;
import dev.struchkov.yookassa.sdk.model.YooKassaProp;
import dev.struchkov.yookassa.sdk.model.webhook.YooKassaNotification;
import io.smallrye.mutiny.Uni;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;

import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.QueryParam;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Response;

import static java.lang.Boolean.TRUE;

@Slf4j
@Path("yookassa")
@RequiredArgsConstructor
public class YooKassaWebhookController {

    private final YooKassaProp yooKassaProp;
    private final YooKassaWebhookConsumer consumer;

    @POST
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Uni<Response> callback(YooKassaNotification notification, @QueryParam("accessKey") String accessKey) {
        log.info("Получен CallBack от YooKassa: {}", notification);
        if (yooKassaProp != null) {
            final String webhookAccessKey = yooKassaProp.getWebhookAccessKey();
            if (webhookAccessKey != null && (!webhookAccessKey.equals(accessKey))) {
                log.warn("Попытка несанкционированного доступа к YooKassa Webhook. Переданный accessKey: {}. Запрос: {}", accessKey, notification);
                return Uni.createFrom().item(Response.status(403).build());
            }
        }
        return consumer.callback(notification)
                .onItem().ifNull().fail()
                .onItem().ifNotNull().transform(flag -> {
                    if (TRUE.equals(flag)) {
                        return Response.ok().build();
                    } else {
                        return Response.status(405).build();
                    }
                });
    }

}
